==> phplist-2.10.5p0.tgz: lists/admin/lan/fr/admin.php <==
<?php

$lan = array(
  'listofadministrators' => 'Liste des Administrateurs',
'Add a new Administrator' => 'Ajouter un nouvel Administrateur',
  'No Access' => 'Acc&egrave;s interdit',
  'Changes saved' => 'Modifications enregistr&eacute;es',
  'Error adding new admin' => 'Une erreur s&rsquo;est produite en ajoutant un nouvel admin',
  'strAccessExplain' => '<hr/>
<p>D&eacute;terminez les droits d&rsquo;acc&egrave;s pour chaque type de page du syst&egrave;me:</p>
<ul>
<li>Tout: l&rsquo;admin a acc&egrave;s &agrave; cette page sans restrictions</li>
<li>Lecture: l&rsquo;admin peut voir le contenu des pages, mais ne peut rien changer.  Cette option ne fonctionne que pour les pages "utilisateur", "utilisateurs" et "membres".</li>
<li>Aucun: l&rsquo;admin n&rsquo;a pas d\'acc&egrave;s &agrave; cette page</li>
<li>Propri&eacute;taire: l&rsquo;admin a acc&egrave;s &agrave; cette page, mais ne peut voir que les listes dont il est le propri&eacute;taire</li>
</ul>
',
'Edit Administrator' => 'Editer Administrateur',
'Admin Details' => 'D&eacute;tails sur l&rsquo;Admin',
'ID' => 'ID',
'Login Name' => 'Identifiant de connexion',
'Normalised loginname' => 'Identifiant normalis&eacute;',
'Email' => 'Email',
'Time Created' => 'Heure de Cr&eacute;ation',
'Time modified' => 'Derni&egrave;re modification',
'Modified by' => 'Modifi&eacute; par',
'Last time password was changed' => 'Derni&egrave;re fois que le mot de passe a &eacute;t&eacute; modifi&eacute;',
'Is this user Super Admin?' => 'Cet utilisateur est-il Super Admin?',
'Is this account disabled?' => 'Ce compte est-il bloqu&eacute;?',
'Save Changes' => 'Enregistrer les modifications',
'Current set of permissions made default' => 'Utiliser ces droits d&rsquo;acc&egrave;s comme valeurs par d&eacute;faut',
'Done' => 'C&rsquo;est fait',
'OK' => 'OK',
'Deleting' => 'Suppression',
'Login Name (max 25 chars)' => 'Identifiant de Connexion (max 25 chars)',
'Access Details' => 'D&eacute;tail des droits d&rsquo;acc&egrave;s',
'Access Privileges' => 'Droits d\'Acc&egrave;s',
'Type' => 'Type',
'Page' => 'Page',
'Set these permissions as default' => 'Faire de ces valeurs les valeurs par d&eacute;faut',
'Reset to Default' => 'Remettre aux valeurs par d&eacute;faut',
'none' => 'Aucun',
'all' => 'Tout',
'view' => 'Lecture',
'owner' => 'Propri&eacute;taire',

);

?>

==> phplist-2.10.19p0.tgz: lists/admin/lan/fr/admin.php <==
<?php

$lan = array(
  'listofadministrators' => 'Liste des Administrateurs',
'Add a new Administrator' => 'Ajouter un nouvel Administrateur',
  'No Access' => 'Acc&egrave;s interdit',
  'Changes saved' => 'Modifications enregistr&eacute;es',
  'Error adding new admin' => 'Une erreur s&rsquo;est produite en ajoutant un nouvel admin',
  'strAccessExplain' => '<hr/>
<p class="information">D&eacute;terminez les droits d&rsquo;acc&egrave;s pour chaque type de page du syst&egrave;me:</p>
<ul>
<li>Tout: l&rsquo;admin a acc&egrave;s &agrave; cette page sans restrictions</li>
<li>Lecture: l&rsquo;admin peut voir le contenu des pages, mais ne peut rien changer.  Cette option ne fonctionne que pour les pages "utilisateur", "utilisateurs" et "membres".</li>
<li>Aucun: l&rsquo;admin n&rsquo;a pas d\'acc&egrave;s &agrave; cette page</li>
<li>Propri&eacute;taire: l&rsquo;admin a acc&egrave;s &agrave; cette page, mais ne peut voir que les listes dont il est le propri&eacute;taire</li>
</ul>
',
'Edit Administrator' => 'Editer Administrateur',
'Admin Details' => 'D&eacute;tails sur l&rsquo;Admin',
'ID' => 'ID',
'Login Name' => 'Identifiant de connexion',
'Normalised loginname' => 'Identifiant normalis&eacute;',
'Email' => 'Email',
'Time Created' => 'Heure de Cr&eacute;ation',
'Time modified' => 'Derni&egrave;re modification',
'Modified by' => 'Modifi&eacute; par',
'Last time password was changed' => 'Derni&egrave;re fois que le mot de passe a &eacute;t&eacute; modifi&eacute;',
'Is this user Super Admin?' => 'Cet utilisateur est-il Super Admin?',
'Is this account disabled?' => 'Ce compte est-il bloqu&eacute;?',
'Save Changes' => 'Enregistrer les modifications',
'Current set of permissions made default' => 'Utiliser ces droits d&rsquo;acc&egrave;s comme valeurs par d&eacute;faut',
'Done' => 'C&rsquo;est fait',
'OK' => 'OK',
'Deleting' => 'Suppression',
'Login Name (max 25 chars)' => 'Identifiant de Connexion (max 25 chars)',
'Access Details' => 'D&eacute;tail des droits d&rsquo;acc&egrave;s',
'Access Privileges' => 'Droits d\'Acc&egrave;s',
'Type' => 'Type',
'Page' => 'Page',
'Set these permissions as default' => 'Faire de ces valeurs les valeurs par d&eacute;faut',
'Reset to Default' => 'Remettre aux valeurs par d&eacute;faut',
'none' => 'Aucun',
'all' => 'Tout',
'view' => 'Lecture',
'owner' => 'Propri&eacute;taire',

);

?>
